@@ -38,24 +38,19 @@ if TYPE_CHECKING:
     ExProjectDir = Path
 
     class SetFlagFn(Protocol):
-        def __call__(self, flag: bool) -> None:
-            ...
+        def __call__(self, flag: bool) -> None: ...
 
     class UpdatePyprojectTomlFn(Protocol):
-        def __call__(self, setting: str, value: Any) -> None:
-            ...
+        def __call__(self, setting: str, value: Any) -> None: ...
 
     class UseHvcsFn(Protocol):
-        def __call__(self, domain: str | None = None) -> type[HvcsBase]:
-            ...
+        def __call__(self, domain: str | None = None) -> type[HvcsBase]: ...
 
     class UseParserFn(Protocol):
-        def __call__(self) -> type[CommitParser]:
-            ...
+        def __call__(self) -> type[CommitParser]: ...
 
     class UseReleaseNotesTemplateFn(Protocol):
-        def __call__(self) -> None:
-            ...
+        def __call__(self) -> None: ...
 
 
 @pytest.fixture(scope="session")
