@@ -1,8 +1,11 @@
+from __future__ import annotations
+
 import base64
 import glob
 import mimetypes
 import os
 import re
+from typing import TYPE_CHECKING
 from unittest import mock
 from urllib.parse import urlencode
 
@@ -16,6 +19,9 @@ from semantic_release.hvcs.token_auth import TokenAuth
 from tests.const import EXAMPLE_REPO_NAME, EXAMPLE_REPO_OWNER, RELEASE_NOTES
 from tests.util import netrc_file
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 @pytest.fixture
 def default_gh_client():
@@ -538,13 +544,14 @@ def test_asset_upload_url(default_gh_client):
     }
     with requests_mock.Mocker(session=default_gh_client.session) as m:
         m.register_uri("GET", github_api_matcher, json=resp_payload, status_code=200)
-        assert default_gh_client.asset_upload_url(
-            release_id
-        ) == "https://{domain}/repos/{owner}/{repo}/releases/{release_id}/assets".format(
-            domain=default_gh_client.DEFAULT_UPLOAD_DOMAIN,
-            owner=default_gh_client.owner,
-            repo=default_gh_client.repo_name,
-            release_id=release_id,
+        assert (
+            default_gh_client.asset_upload_url(release_id)
+            == "https://{domain}/repos/{owner}/{repo}/releases/{release_id}/assets".format(
+                domain=default_gh_client.DEFAULT_UPLOAD_DOMAIN,
+                owner=default_gh_client.owner,
+                repo=default_gh_client.repo_name,
+                release_id=release_id,
+            )
         )
         assert m.called
         assert len(m.request_history) == 1
@@ -563,7 +570,11 @@ def test_asset_upload_url(default_gh_client):
 @pytest.mark.parametrize("status_code", (200, 201))
 @pytest.mark.parametrize("mock_release_id", range(3))
 def test_upload_asset_succeeds(
-    default_gh_client, example_changelog_md, status_code, mock_release_id
+    init_example_project: None,
+    default_gh_client: Github,
+    example_changelog_md: Path,
+    status_code: int,
+    mock_release_id: int,
 ):
     label = "abc123"
     urlparams = {"name": example_changelog_md.name, "label": label}
@@ -617,7 +628,11 @@ def test_upload_asset_succeeds(
 @pytest.mark.parametrize("status_code", (400, 404, 429, 500, 503))
 @pytest.mark.parametrize("mock_release_id", range(3))
 def test_upload_asset_fails(
-    default_gh_client, example_changelog_md, status_code, mock_release_id
+    init_example_project: None,
+    default_gh_client: Github,
+    example_changelog_md: Path,
+    status_code: int,
+    mock_release_id: int,
 ):
     label = "abc123"
     urlparams = {"name": example_changelog_md.name, "label": label}
@@ -704,9 +719,7 @@ def test_upload_dists_when_release_id_found(
         default_gh_client, "upload_asset"
     ) as mock_upload_asset, mock.patch.object(
         glob, "glob"
-    ) as mock_glob_glob, mock.patch.object(
-        os.path, "isfile"
-    ) as mock_os_path_isfile:
+    ) as mock_glob_glob, mock.patch.object(os.path, "isfile") as mock_os_path_isfile:
         # Skip check as the filenames deliberately don't exists for testing
         mock_os_path_isfile.return_value = True
 
